@@ -7,6 +7,7 @@
 using namespace Rcpp;
 using namespace RNifti;
 
+typedef std::vector<int> int_vector;
 typedef std::vector<float> float_vector;
 
 ::mat44 matrixToXform (const SEXP _matrix, bool *valid = NULL)
@@ -89,6 +90,37 @@ BEGIN_RCPP
 END_RCPP
 }
 
+RcppExport SEXP writeNiftiRgb (SEXP _red, SEXP _green, SEXP _blue, SEXP _file, SEXP _reference)
+{
+BEGIN_RCPP
+    const NiftiImage reference(_reference, false, true);
+    NiftiImage image = reference;
+    NumericVector red(_red);
+    NumericVector green(_green);
+    NumericVector blue(_blue);
+    
+    image->datatype = DT_RGB24;
+    nifti_datatype_sizes(DT_RGB24, &image->nbyper, &image->swapsize);
+    
+    unsigned char *data = (unsigned char *) calloc(image->nvox, 3);
+    for (size_t i=0; i<image->nvox; i++)
+    {
+        data[3*i] = static_cast<unsigned char>(red[i] * 255.0);
+        data[3*i+1] = static_cast<unsigned char>(green[i] * 255.0);
+        data[3*i+2] = static_cast<unsigned char>(blue[i] * 255.0);
+    }
+    
+    image->data = (void *) data;
+    image->scl_slope = 0.0;
+    image->scl_inter = 0.0;
+    image->cal_min = 0.0;
+    image->cal_max = 0.0;
+    
+    image.toFile(as<std::string>(_file));
+    return R_NilValue;
+END_RCPP
+}
+
 RcppExport SEXP updateNifti (SEXP _image, SEXP _reference, SEXP _datatype)
 {
 BEGIN_RCPP
@@ -405,6 +437,92 @@ BEGIN_RCPP
 END_RCPP
 }
 
+RcppExport SEXP indexVector (SEXP _image, SEXP _indices)
+{
+BEGIN_RCPP
+    const NiftiImage image(_image, true, true);
+    if (image.isNull())
+        Rf_error("Cannot index into a NULL image");
+    else if (image->data == NULL)
+        return LogicalVector(Rf_length(_indices), NA_LOGICAL);
+    else
+    {
+        const IntegerVector indices(_indices);
+        const NiftiImageData data = image.data();
+        if (data.isFloatingPoint() || data.isScaled())
+        {
+            NumericVector result(indices.length());
+            for (int i=0; i<indices.length(); i++)
+                result[i] = (size_t(indices[i]) > data.size() ? NA_REAL : data[indices[i] - 1]);
+            return result;
+        }
+        else
+        {
+            IntegerVector result(indices.length());
+            for (int i=0; i<indices.length(); i++)
+                result[i] = (size_t(indices[i]) > data.size() ? NA_INTEGER : data[indices[i] - 1]);
+            return result;
+        }
+    }
+END_RCPP
+}
+
+RcppExport SEXP indexList (SEXP _image, SEXP _indices)
+{
+BEGIN_RCPP
+    const NiftiImage image(_image, true, true);
+    if (image.isNull())
+        Rf_error("Cannot index into a NULL image");
+    else if (image->data == NULL)
+        return LogicalVector(1, NA_LOGICAL);
+    else
+    {
+        const List indices(_indices);
+        const std::vector<int> dim = image.dim();
+        const int nDims = indices.length();
+        std::vector<size_t> strides(nDims);
+        std::vector<int_vector> locs(nDims);
+        int_vector sizes(nDims);
+        std::vector<size_t> cumulativeSizes(nDims);
+        size_t count = 1;
+        for (int i=0; i<nDims; i++)
+        {
+            strides[i] = (i == 0 ? 1 : strides[i-1] * dim[i-1]);
+            locs[i] = as<int_vector>(indices[i]);
+            sizes[i] = locs[i].size();
+            cumulativeSizes[i] = (i == 0 ? 1 : cumulativeSizes[i-1] * sizes[i-1]);
+            count *= sizes[i];
+        }
+        
+        const NiftiImageData data = image.data();
+        if (data.isFloatingPoint() || data.isScaled())
+        {
+            NumericVector result(count);
+            for (size_t j=0; j<count; j++)
+            {
+                size_t loc = 0;
+                for (int i=0; i<nDims; i++)
+                    loc += (locs[i][(j / cumulativeSizes[i]) % sizes[i]] - 1) * strides[i];
+                result[j] = (loc >= data.size() ? NA_REAL : data[loc]);
+            }
+            return result;
+        }
+        else
+        {
+            IntegerVector result(count);
+            for (size_t j=0; j<count; j++)
+            {
+                size_t loc = 0;
+                for (int i=0; i<nDims; i++)
+                    loc += (locs[i][(j / cumulativeSizes[i]) % sizes[i]] - 1) * strides[i];
+                result[j] = (loc >= data.size() ? NA_INTEGER : data[loc]);
+            }
+            return result;
+        }
+    }
+END_RCPP
+}
+
 RcppExport SEXP rescaleImage (SEXP _image, SEXP _scales)
 {
 BEGIN_RCPP
@@ -429,6 +547,7 @@ static R_CallMethodDef callMethods[] = {
     { "niftiVersion",   (DL_FUNC) &niftiVersion,    1 },
     { "readNifti",      (DL_FUNC) &readNifti,       3 },
     { "writeNifti",     (DL_FUNC) &writeNifti,      3 },
+    { "writeNiftiRgb",  (DL_FUNC) &writeNiftiRgb,   5 },
     { "updateNifti",    (DL_FUNC) &updateNifti,     3 },
     { "niftiHeader",    (DL_FUNC) &niftiHeader,     1 },
     { "analyzeHeader",  (DL_FUNC) &analyzeHeader,   1 },
@@ -439,6 +558,8 @@ static R_CallMethodDef callMethods[] = {
     { "getRotation",    (DL_FUNC) &getRotation,     2 },
     { "getAddresses",   (DL_FUNC) &getAddresses,    1 },
     { "hasData",        (DL_FUNC) &hasData,         1 },
+    { "indexVector",    (DL_FUNC) &indexVector,     2 },
+    { "indexList",      (DL_FUNC) &indexList,       2 },
     { "rescaleImage",   (DL_FUNC) &rescaleImage,    2 },
     { "pointerToArray", (DL_FUNC) &pointerToArray,  1 },
     { NULL, NULL, 0 }
@@ -458,6 +579,7 @@ void R_init_RNifti (DllInfo *info)
     R_RegisterCCallable("RNifti",   "nii_image_unload",     (DL_FUNC) &nifti_image_unload);
     R_RegisterCCallable("RNifti",   "nii_image_free",       (DL_FUNC) &nifti_image_free);
     
+    R_RegisterCCallable("RNifti",   "nii_is_inttype",       (DL_FUNC) &nifti_is_inttype);
     R_RegisterCCallable("RNifti",   "nii_datatype_sizes",   (DL_FUNC) &nifti_datatype_sizes);
     R_RegisterCCallable("RNifti",   "nii_datatype_string",  (DL_FUNC) &nifti_datatype_string);
     R_RegisterCCallable("RNifti",   "nii_units_string",     (DL_FUNC) &nifti_units_string);
