@@ -109,6 +109,18 @@ test_that("image objects can be manipulated", {
     image <- updateNifti(image, datatype="float")
     expect_equal(image$datatype, 16L)
     
+    # Empty values are ignored (with a warning)
+    expect_warning(image$intent_code <- integer(0))
+    
+    # Only the first value will be used (with a warning)
+    expect_warning(image$intent_code <- 1002:1005)
+    expect_equal(image$intent_code, 1002L)
+    
+    # Vector-valued fields must have the right length
+    expect_error(image$srow_x <- 1.0)
+    image$srow_x[1] <- 1.0
+    expect_equal(image$srow_x[1], 1.0)
+    
     image <- readNifti(imagePath, internal=TRUE)
     image <- RNifti:::rescaleNifti(image, c(0.5,0.5,0.5))
     expect_equal(pixdim(image), c(5,5,5))
